#
# spec file for package hp2xx
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           hp2xx
Version:        3.4.4
Release:        2.2
Summary:        Converts HP-GL Plotter Language into a Variety of Formats
License:        GPL-2.0+
Group:          Productivity/Graphics/Convertors
Url:            https://www.gnu.org/software/hp2xx/hp2xx.html
Source:         https://ftp.gnu.org/gnu/hp2xx/hp2xx-%{version}.tar.gz
# PATCH-MISSING-TAG -- See http://wiki.opensuse.org/openSUSE:Packaging_Patches_guidelines
Patch0:         hp2xx-3.4.2-fix.patch
# PATCH-FIX-SUSE  fixes rpm lint error
Patch1:         fix-stringcompare.patch
# PATCH-MISSING-TAG -- See http://wiki.opensuse.org/openSUSE:Packaging_Patches_guidelines
Patch2:         hp2xx-3.4.2-png-deprecated.patch
# PATCH-FIX-UPSTREAM hp2xx-texinfo-5.0.patch dimstar@opensuse.org -- Escape '@' in .texi file
Patch3:         hp2xx-texinfo-5.0.patch
BuildRequires:  libjpeg-devel
BuildRequires:  libpng-devel
BuildRequires:  libtiff-devel
BuildRequires:  xorg-x11-libX11-devel
Requires(post): %{install_info_prereq}
Requires(preun): %{install_info_prereq}
%if 0%{?suse_version} > 1220
BuildRequires:  makeinfo
%endif

%description
The hp2xx program is a versatile tool for converting vector graphics
data given in Hewlett-Packard's HP-GL plotter language into a variety
of popular graphics formats, both vector and raster.

%prep
%setup -q
%patch -P 0 -p1 -b .fix
%patch -P 1 -p1
%patch -P 2
%patch -P 3 -p1

%build
make %{?_smp_mflags} CC="gcc" OPTFLAGS="%{optflags}" LFLAGS="-L/usr/X11R6/%{_lib}"

%install
mkdir -p %{buildroot}/{usr/bin,%{_infodir},%{_mandir}/man1}
make bindir=%{buildroot}%{_bindir} \
     infodir=%{buildroot}/%{_infodir} \
     mandir=%{buildroot}/%{_mandir} install STRIP=true

%files
%doc AUTHORS CHANGES README TODO copying doc/readme doc/changes doc/hp_cmds.lst
%{_bindir}/hp2xx
%{_mandir}/man1/hp2xx.1%{ext_man}
%{_infodir}/hp2xx.info%{ext_info}

%post
%install_info --info-dir=%{_infodir} %{_infodir}/%{name}.info.gz

%preun
%install_info_delete --info-dir=%{_infodir} %{_infodir}/%{name}.info.gz

%changelog
* Thu Feb 22 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Sun Feb 18 2018 avindra@opensuse.org
- Update to  3.4.4
  * New features:
  - Added experimental support for scalable (truetype) fonts based
    on the freetype2 library. To enable this, obtain a suitable
    fixed-width font (such as Bitstream Vera Mono available from
    www.gnome.org/fonts) and add
    '-DSTROKED_FONTS=\"/path/to/this/truetype/font.ttf\"' in the
    DEFINES section of the Makefile)
  - DXF header improved, and line width and color support added
  - Added support for the rectangle mode within PE mode
  - Added NR as another end-of-image marker in multi-image files
  - hp2xx now tries to print the offending section of the input
    file when it encounters an error.
  - Added a new commandline option, -M <pen> to redirect pen 0
    drawing commands to any other, ideally unused pen number.
    This works around the problem that redefining PC0 also changes
    the background color of raster images (but not vector files
    such as eps).
  * Bug fixes:
  - penwidth was erroneously set to the default 0.1 mm after
    drawing a label
  - xfig and rgip output did not yet handle the changed pencolor
    and width settings
  - polygons sometimes had the wrong sections filled in for some
    of the scanlines
  - forcing penwidth via the -p commandline option no longer
    worked for the conventional values between 1 and 9
  - Simplified HPGL output could contain values in exponential
    notation (which is illegal in HPGL1)
  - Default miter limit in eps and pdf output was way too large
  - Using the -ansi compiler flag (as even suggested by the
    supplied Makefiles) could result in a broken binary (due to
    missing function prototypes) on some platforms
  - the size of the raster buffer was miscalculated in some
    circumstances
  - DT implementation was both incorrect and incomplete
  - AA with CT set to 'deviation distance' gave wrong results or
    even crashed the program
  - page counting of multi-image files was not always correct,
    rendering some images inaccessible, or causing the generation
    of blank image files)
  - SP in PE mode did not update the pen count, potentially
    resulting in color loss in the raster modes.
  - Using -h, -? or even -help for help no longer generates an
    error message before the help text is shown.
- includes 3.4.3
  * New features:
  - Raster graphics modes now use correctly scaled penwidths
  - Added support for (most of) the LA, line attributes command
    (cap/join types best supported in eps,fig and pdf for now)
  - Added support for the CR (relative color range) command
  - Added support for the IR (input reference points as percentage
    of current limits) command
  - Added support for the OW (output clipping window) command
  - hp2xx now recognizes (and ignores) the VS command to reduce
    number of runtime warnings
  - hp2xx now ignores stray Escape characters among HPGL commands
  - EMF export is now also available as an option on non-Windows
    builds if libEMF (http://libemf.sourceforge.net) is installed
  - hp2xx now translates FP commands into EP to show the outlines
    when the -n, --nofill option is used. (Previously polygon
    commands were ignored in that case unless they contained an
    explicit EP as well. This was particularly unfortunate in the
    case of polygon-derived text)
  - Added new commandline option -e, --extraclip <unit> for
    additional margin around clip regions. Some programs apparently
    miscalculate their frames.
  - Input files containing several plots are now rendered as
    separate images, even if the -P option is not used. Output file
    names are numbered starting from the second file, i.e. file.plt
    yields file.png file.1.png file.2.png.
  - TIFF creation on stdout now uses a safer method of generating
    and accessing its temporary file on Unix.
  - Added a new output format, G-code for CNC engraving
  * Bug fixes:
  - hp2xx now ignores SC commands with invalid parameters
  - hp2xx now ignores PS0
  - IW without parameters now does not cause clipping when P1,P2
    are still set to the 'hardware defaults'.
  - AC support in 3.4.2 slowed down the polygon fill code
  - raster mode was allocating a big 8 bit per pixel memory
    buffer even when the pen data would fit in 4bpp
  - PDF output would fold the image in some cases
  - The RO/IW fix in 3.4.2 broke other cases, fixed again.
  - The DXF header was a bit too minimalistic for some readers
  - Dots drawn for PUPDPU sequences were not clipped by IW
  - Unsupported subtypes 6 and 7 of SD and AD (weight & typeface)
    caused an error exit instead of simply being ignored
  - extremely short line segments could confuse the pattern state
    machine, resulting in no or extraneous lines being drawn
  - BP did not handle kind=5 (autorotation control). This could
    lead to misinterpretation of further arguments to BP,
    specifically title strings
  - Escape sequences inside PJL headers (two or more header lines
    starting with 'Esc-12345X') are now handled gracefully
  - Removed memory leak in the X11 previewers' zoom function
  - PDF output could omit lines in some cases
  - PM2 did not close the current polygon if necessary
  - Polygon fill range was not always initialized correctly
  - Compile fix for HPUX11 ansi compiler (add whitespace to work
    around what is probably a compiler bug)
  - Vertices of filled polygons were omitted from calculation of
    actual plot size
  - added ROWSPERSTRIP header parameter to TIFF files, as some
    programs rely on its presence
  - Dots for PUPDPU got drawn for PDPA as well, which made
    consecutive dashed lines restart the dash pattern for each
    segment instead of carrying over the remainder of the pattern
    from the previous one.
  - Removed the checks preventing negative or large offsets to be
    defined with the -o and -O commandline options
  - The viewbox given in the SVG header was too small
  - Closed several memory leaks (mainly important for multi-file
    operation).
  - The documentation was outdated in several aspects.
  - The SVG output used integral linewidths only roughly
    corresponding to the original values.
  - Files that explicitly asked for default arc precision (by
    providing a zero tolerance value) were not handled correctly
  - Text penwidth was always the same as that in use for
    linedrawing. This is now fixed, and the SD option for forcing
    this behaviour is now honored.
  - Some warning messages were emitted even in quiet mode.
- rebase hp2xx-3.4.2-fix.patch
- rebase hp2xx-3.4.2-png-deprecated.patch
- drop hp2xx-3.4.2-implicit-decls.patch (fixed upstream)
- add fix-stringcompare.patch (fixes rpm lint error)
* Sun Aug  2 2015 mpluskal@suse.com
- Use url for source
- Upate info file scriplets and their dependencies
- Cleanup spec file with spec-cleaner
* Wed Feb 18 2015 dimstar@opensuse.org
- Add hp2xx-texinfo-5.0.patch: Escape '@' inside .texi files. Fixes
  info generation using texinfo 5.0.
* Tue Sep 11 2012 coolo@suse.com
- add makeinfo as explicit buildrequire
* Thu Sep  6 2012 pgajdos@suse.com
- builds also against libpng15
  * extended png-deprecated.patch
* Tue Jan 10 2012 crrodriguez@opensuse.org
- Fix build, missing libjpeg-devel buildrequires
- Do not use xorg-x11-devel but only xorg-x11-libX11-devel
* Wed Oct  5 2011 uli@suse.com
- cross-build fix: use %%__cc macro
* Thu Feb 25 2010 crrodriguez@opensuse.org
- fix deprecated messages with new libpng
* Tue Nov 24 2009 crrodriguez@opensuse.org
- fix implicit declarations
* Wed Aug 26 2009 mls@suse.de
- make patch0 usage consistent
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Jan 20 2006 schwab@suse.de
- Don't strip binaries.
* Sun Jan 11 2004 adrian@suse.de
- build as user
* Thu Apr 24 2003 ro@suse.de
- fix install_info --delete call and move from preun to postun
* Tue Feb 11 2003 nadvornik@suse.cz
- added install_info macros
* Mon Jul 29 2002 meissner@suse.de
- fixed to work on non i386.
* Fri Jul 26 2002 nadvornik@suse.cz
- updated to 3.4.2
* Wed Apr 24 2002 nadvornik@suse.cz
- used %%{_lib} macro
* Thu Jan 31 2002 ro@suse.de
- changed neededforbuild <libpng> to <libpng-devel-packages>
* Thu Mar  8 2001 nadvornik@suse.cz
- update to 3.4.0
* Thu Oct 26 2000 nadvornik@suse.cz
- new package
